@@ -21,7 +21,7 @@ use vec_map::VecMap;
 use crate::calling::variants::preprocessing::write_observations;
 use crate::utils;
 use crate::variants::evidence::observation::expected_depth;
-use crate::variants::evidence::observation::{IndelOperations, Observation, ReadPosition, Strand};
+use crate::variants::evidence::observation::{Observation, ReadPosition, Strand};
 use crate::variants::model;
 use crate::variants::model::{
     bias::Biases, bias::DivIndelBias, bias::ReadOrientationBias, bias::ReadPositionBias,
@@ -178,7 +178,7 @@ impl Call {
                     i,
                     match sample_info.biases.divindel_bias() {
                         DivIndelBias::None => b'.',
-                        DivIndelBias::Some { .. } => b'#',
+                        DivIndelBias::Some { .. } => b'*',
                     },
                 );
 
@@ -216,10 +216,10 @@ impl Call {
                                     ReadPosition::Some => '*',
                                 },
                                 if obs.softclipped { '$' } else { '.' },
-                                match obs.indel_operations {
-                                    IndelOperations::Major => '*',
-                                    IndelOperations::Other => '#',
-                                    IndelOperations::None => '.',
+                                if obs.has_alt_indel_operations {
+                                    '*'
+                                } else {
+                                    '.'
                                 },
                             )
                         }),
@@ -324,7 +324,7 @@ impl Call {
                 !event_probs.values().any(|prob| prob.is_nan()),
                 "bug: event probability is NaN but not all observations are empty for record at {}:{}",
                 str::from_utf8(&self.chrom).unwrap(),
-                self.pos,
+                self.pos + 1,
             );
             for (event, prob) in event_probs {
                 let prob = PHREDProb::from(prob).abs() as f32;
@@ -417,7 +417,7 @@ pub(crate) struct Variant {
     #[getset(get = "pub(crate)")]
     event_probs: Option<HashMap<String, LogProb>>,
     #[builder(default = "None")]
-    observations: Option<Vec<Observation<ReadPosition, IndelOperations>>>,
+    observations: Option<Vec<Observation<ReadPosition>>>,
     #[builder(default)]
     #[getset(get = "pub(crate)")]
     sample_info: Vec<Option<SampleInfo>>,
@@ -512,7 +512,7 @@ impl VariantBuilder {
 pub(crate) struct SampleInfo {
     allelefreq_estimate: AlleleFreq,
     #[builder(default = "Vec::new()")]
-    observations: Vec<Observation<ReadPosition, IndelOperations>>,
+    observations: Vec<Observation<ReadPosition>>,
     biases: Biases,
 }
 
